@@ -23,6 +23,9 @@ from clipboard.formats import ClipboardFormat
 
 hMem = HANDLE  # Type Alias
 logger = get_logger(__name__)
+GMEM_MOVEABLE = 0x0002
+GMEM_ZEROINIT = 0x0040
+GMEM_DDESHARE = 0x2000
 
 
 def get_clipboard(format: Union[int, ClipboardFormat] = None) -> Optional[str]:
@@ -142,16 +145,23 @@ class Clipboard:
             return html
 
         else:
-            return None
+            string: ctypes.Array[ctypes.c_byte] = (
+                ctypes.c_byte * self.size
+            ).from_address(
+                int(self.address)  # type: ignore
+            )
+            text: str = bytearray(string).decode(encoding="utf-8")[:-1]
+
+            return text
 
     def set_clipboard(
         self, content: str, format: Union[int, ClipboardFormat] = None
-    ) -> None:
+    ) -> HANDLE:
         """Set clipboard."""
 
-        _: HANDLE = self._set_clipboard(content, format)
+        set_handle: HANDLE = self._set_clipboard(content, format)
 
-        return None
+        return set_handle
 
     def _set_clipboard(
         self, content: str, format: Union[int, ClipboardFormat] = None
@@ -174,18 +184,13 @@ class Clipboard:
         alloc_handle: HANDLE
         if format == ClipboardFormat.CF_UNICODETEXT.value:
 
-            # GMEM_DDESHARE = 0x2000
-            GMEM_MOVEABLE = 0x0002
-            GMEM_ZEROINIT = 0x0040
-
-            # Needs a special encoding...
             content_bytes: bytes = content.encode(encoding="utf-16le")
 
             alloc_handle = GlobalAlloc(
                 GMEM_MOVEABLE | GMEM_ZEROINIT, len(content_bytes) + 2
             )
-            pcontents: LPVOID = GlobalLock(alloc_handle)
-            ctypes.memmove(pcontents, content_bytes, len(content_bytes))
+            contents_ptr: LPVOID = GlobalLock(alloc_handle)
+            ctypes.memmove(contents_ptr, content_bytes, len(content_bytes))
             GlobalUnlock(alloc_handle)
 
             set_handle = SetClipboardData(format, alloc_handle)
@@ -194,25 +199,28 @@ class Clipboard:
             format == ClipboardFormat.CF_HTML.value
             or format == ClipboardFormat.HTML_Format.value
         ):
-            # GMEM_DDESHARE = 0x2000
-            GMEM_MOVEABLE = 0x0002
-            GMEM_ZEROINIT = 0x0040
 
-            # Needs a special encoding...
             html_content_bytes: bytes = content.encode(encoding="utf-16le")
 
             alloc_handle = GlobalAlloc(
                 GMEM_MOVEABLE | GMEM_ZEROINIT, len(content) + 2
             )
-            pcontents: LPVOID = GlobalLock(alloc_handle)  # type: ignore
-            ctypes.memmove(pcontents, html_content_bytes, len(content))
+            contents_ptr: LPVOID = GlobalLock(alloc_handle)  # type: ignore
+            ctypes.memmove(contents_ptr, html_content_bytes, len(content))
             GlobalUnlock(alloc_handle)
 
             set_handle = SetClipboardData(format, alloc_handle)
         else:
-            raise Exception(
-                f"{format} not supported for setting to clipboard."
+            content_bytes: bytes = content.encode(encoding="utf-8")
+
+            alloc_handle = GlobalAlloc(
+                GMEM_MOVEABLE, len(content_bytes) + 1
             )
+            contents_ptr: LPVOID = GlobalLock(alloc_handle)
+            ctypes.memmove(contents_ptr, content_bytes, len(content_bytes))
+            GlobalUnlock(alloc_handle)
+
+            set_handle = SetClipboardData(format, alloc_handle)
 
         if set_handle is False:
             # handle will be set to NULL
@@ -275,11 +283,11 @@ class Clipboard:
         self.opened = True
         return OpenClipboard(handle)
 
-    def _close(self) -> None:
+    def _close(self) -> bool:
 
         self.opened = False
         self._unlock()
-        CloseClipboard()
+        return CloseClipboard()
 
     def _lock(self, handle: HANDLE) -> LPVOID:
         self.locked = True
